package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallMajorRanking;

/**
 * 专业榜单Service接口
 *
 * @author LCL
 * @date 2023-10-24
 */
public interface IMallMajorRankingService
{
    /**
     * 查询专业榜单
     *
     * @param rankingId 专业榜单主键
     * @return 专业榜单
     */
    public MallMajorRanking selectMallMajorRankingByRankingId(Long rankingId);

    /**
     * 查询专业榜单列表
     *
     * @param mallMajorRanking 专业榜单
     * @return 专业榜单集合
     */
    public List<MallMajorRanking> selectMallMajorRankingList(MallMajorRanking mallMajorRanking);

    /**
     * 新增专业榜单
     *
     * @param mallMajorRanking 专业榜单
     * @return 结果
     */
    public int insertMallMajorRanking(MallMajorRanking mallMajorRanking);

    /**
     * 修改专业榜单
     *
     * @param mallMajorRanking 专业榜单
     * @return 结果
     */
    public int updateMallMajorRanking(MallMajorRanking mallMajorRanking);

    /**
     * 批量删除专业榜单
     *
     * @param rankingIds 需要删除的专业榜单主键集合
     * @return 结果
     */
    public int deleteMallMajorRankingByRankingIds(Long[] rankingIds);

    /**
     * 删除专业榜单信息
     *
     * @param rankingId 专业榜单主键
     * @return 结果
     */
    public int deleteMallMajorRankingByRankingId(Long rankingId);

    /**
     * 专业榜单信息列表
     *
     * @param type 类型：0-排行榜，1-专业强校，2-省份强校，3-非正常研究
     * @return 结果
     */
    public List<Map<String, Object>> selectMajorRankingList(String type);

    /**
     * 专业榜单信息学校列表
     *
     * @param rankingId 专业榜单主键
     * @return 结果
     */
    public List<Map<String, Object>> selectMajorRankingSchoolList(Long rankingId);

    /**
     * 专业榜单信息浏览量+1
     *
     * @param rankingId 专业榜单主键
     * @return 结果
     */
    public int updateMallMajorRankingViewNumByRankingId(Long rankingId);
}
